@@ -16,6 +16,10 @@
 #include <QStringBuilder>
 #include <chrono>
 #include <unistd.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <dirent.h>
+#include <string.h>
 
 ApplicationManager1Service::~ApplicationManager1Service() = default;
 
@@ -60,6 +64,10 @@ void ApplicationManager1Service::initService(QDBusConnection &connection) noexce
         std::terminate();
     }
 
+    if (m_compatibilityManager.reset(new (std::nothrow) CompatibilityManager()); !m_compatibilityManager) {
+        qWarning() << "new CompatibilityManager failed.";
+    }
+
     connect(&m_watcher, &QFileSystemWatcher::directoryChanged, this, &ApplicationManager1Service::ReloadApplications);
     auto unhandled = m_watcher.addPaths(getDesktopFileDirs());
     for (const auto &dir : unhandled) {
@@ -134,6 +142,8 @@ void ApplicationManager1Service::initService(QDBusConnection &connection) noexce
 
     auto needLaunch = scanAutoStart();
 
+    autoRemoveFromDesktop();
+
     scanInstances();
 
     auto storagePtr = m_storage.lock();
@@ -169,44 +179,50 @@ void ApplicationManager1Service::initService(QDBusConnection &connection) noexce
     if (flag.open(QFile::WriteOnly | QFile::Truncate)) {
         flag.write(sessionId, sessionId.size());
     }
-
-    constexpr auto XSettings = "org.deepin.dde.XSettings1";
-
-    auto *watcher = new (std::nothrow)
-        QDBusServiceWatcher{XSettings, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForRegistration, this};
-
-    auto *sigCon = new (std::nothrow) QMetaObject::Connection{};
-
-    auto singleSlot = [watcher, sigCon, autostartMap = std::move(needLaunch)]() {
-        QObject::disconnect(*sigCon);
-        delete sigCon;
-        qDebug() << XSettings << "is registered.";
-
-        for (const auto &[app, realExec] : autostartMap.asKeyValueRange()) {
+    auto value = QString::fromLocal8Bit(qgetenv("XDG_SESSION_TYPE"));
+    if (!value.isEmpty() && value == QString::fromLocal8Bit("wayland")) {
+        for (const auto &[app, realExec] : needLaunch.asKeyValueRange()) {
             app->Launch({}, {}, {}, realExec);
         }
+    } else {
+         constexpr auto XSettings = "org.deepin.dde.XSettings1";
 
-        watcher->deleteLater();
-    };
+        auto *watcher = new (std::nothrow)
+            QDBusServiceWatcher{XSettings, QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForRegistration, this};
 
-    if (watcher != nullptr) {
-        *sigCon = connect(watcher, &QDBusServiceWatcher::serviceRegistered, singleSlot);
-    }
+        auto *sigCon = new (std::nothrow) QMetaObject::Connection{};
 
-    auto msg =
-        QDBusMessage::createMethodCall("org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus", "NameHasOwner");
-    msg << XSettings;
+        auto singleSlot = [watcher, sigCon, autostartMap = std::move(needLaunch)]() {
+            QObject::disconnect(*sigCon);
+            delete sigCon;
+            qDebug() << XSettings << "is registered.";
 
-    auto reply = QDBusConnection::sessionBus().call(msg);
-    if (reply.type() != QDBusMessage::ReplyMessage) {
-        qWarning() << "call org.freedesktop.DBus::NameHasOwner failed, skip autostart:" << reply.errorMessage();
-        // The connection should not be deleted, failure to call org.freedesktop.DBus::NameHasOwner does not mean that the
-        // XSettings service is invalid.
-        return;
-    }
+            for (const auto &[app, realExec] : autostartMap.asKeyValueRange()) {
+                app->Launch({}, {}, {}, realExec);
+            }
 
-    if (reply.arguments().first().toBool()) {
-        singleSlot();
+            watcher->deleteLater();
+        };
+
+        if (watcher != nullptr) {
+            *sigCon = connect(watcher, &QDBusServiceWatcher::serviceRegistered, singleSlot);
+        }
+
+        auto msg =
+            QDBusMessage::createMethodCall("org.freedesktop.DBus", "/org/freedesktop/DBus", "org.freedesktop.DBus", "NameHasOwner");
+        msg << XSettings;
+
+        auto reply = QDBusConnection::sessionBus().call(msg);
+        if (reply.type() != QDBusMessage::ReplyMessage) {
+            qWarning() << "call org.freedesktop.DBus::NameHasOwner failed, skip autostart:" << reply.errorMessage();
+            // The connection should not be deleted, failure to call org.freedesktop.DBus::NameHasOwner does not mean that the
+            // XSettings service is invalid.
+            return;
+        }
+
+        if (reply.arguments().first().toBool()) {
+            singleSlot();
+        }
     }
 }
 
@@ -632,12 +648,91 @@ void ApplicationManager1Service::updateApplication(const QSharedPointer<Applicat
     }
 
     if (destApp->m_desktopSource != desktopFile and destApp->isAutoStart()) {
-        destApp->setAutoStart(false);
         destApp->m_desktopSource = std::move(desktopFile);
-        destApp->setAutoStart(true);
     }
 }
 
+// 删除桌面无效的快捷方式
+ void ApplicationManager1Service::autoRemoveFromDesktop() noexcept
+ {
+    auto dirPath = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+    if (dirPath.isEmpty()) {
+        return;
+    }
+
+    DIR *dir = opendir(dirPath.toLocal8Bit().constData());
+    if (dir == nullptr) {
+        qWarning() << "open dir :" << dirPath << "failed";
+        return;
+    }
+
+    struct dirent *entry;
+    while ((entry = readdir(dir)) != nullptr) {
+        // 跳过 . 和 .. 目录
+        if (strcmp(entry->d_name, ".") == 0 || strcmp(entry->d_name, "..") == 0) {
+            continue;
+        }
+
+        const char *suffix = ".desktop";
+        const char *entryName = entry->d_name;
+        int indexSuffix = strlen(suffix)-1;
+        int index = strlen(entryName)-1;
+        bool isDesktopFile = true;
+       
+        if (index < indexSuffix) {
+            continue;
+        }
+        
+        while (indexSuffix >= 0) {
+            if(suffix[indexSuffix--] != entryName[index--]){
+                isDesktopFile = false;
+                break;
+            }
+        }
+
+        if (!isDesktopFile) {
+            qWarning() << "entry->d_name not DesktopFile:" << entry->d_name;
+            continue;
+        }
+
+        qWarning() << "entry->d_name DesktopFile:" << entry->d_name;
+
+        std::string entryPath = dirPath.toStdString() + "/" + entry->d_name;
+
+        struct stat statbuf;
+        if (lstat(entryPath.c_str(), &statbuf) == -1) {
+            qWarning() << "lstat failed:" << entryPath.c_str();
+            continue;
+        }
+
+        // 检查是否是符号链接
+        if (S_ISLNK(statbuf.st_mode)) {
+            char target[4096];
+            ssize_t len = readlink(entryPath.c_str(), target, sizeof(target) - 1);
+            if (len == -1) {
+                qWarning() << "readlink failed:" << entryPath.c_str();
+                continue;
+            }
+            target[len] = '\0';
+
+            QFileInfo fileInfo{entryPath.c_str()};
+            // 检查符号链接的目标是否存在
+            struct stat targetStat;
+            if (lstat(target, &targetStat) == -1) {                     
+                QFile file{fileInfo.filePath()};
+                auto success = file.remove();
+                if (!success) {
+                    qWarning() << "remove desktop file failed:" << file.errorString();
+                }else {
+                    qWarning() << "remove desktop file success:" << fileInfo.filePath();
+                } 
+            }
+        }
+    }
+
+    closedir(dir);
+ }
+
 void ApplicationManager1Service::ReloadApplications()
 {
     if (calledFromDBus() && !m_reloadTimer.isActive()) {
@@ -783,5 +878,50 @@ QString ApplicationManager1Service::addUserApplication(const QVariantMap &deskto
         return {};
     }
 
+    m_mimeManager->updateMimeCache(dir);
+
     return appId;
 }
+
+
+void ApplicationManager1Service::deleteUserApplication(const QString &app_id) noexcept
+{ 
+    if (app_id.isEmpty()) {
+        safe_sendErrorReply(QDBusError::Failed, "app id name is empty.");
+        return;
+    }
+
+    QDir xdgDataHome;
+    QString dir{getXDGDataHome() + "/applications"};
+    if (!xdgDataHome.mkpath(dir)) {
+        safe_sendErrorReply(QDBusError::Failed, "couldn't create directory of user applications.");
+        return;
+    }
+
+    xdgDataHome.setPath(dir);
+    const auto &filePath = xdgDataHome.filePath(app_id+".desktop");
+
+    if (QFileInfo info{filePath}; !info.exists() || !info.isFile()) {
+        safe_sendErrorReply(QDBusError::Failed, QString{"file not exists:%1"}.arg(info.absoluteFilePath()));
+        return;
+    }
+
+/*
+    auto apps = findApplicationsByIds({app_id});
+    if (apps.isEmpty()) {
+        qWarning() << "we can't find corresponding application in ApplicationManagerService.";
+    }
+
+    for (const auto &app : apps) {
+        app->setMimeTypes({});
+    }
+*/
+    if (!QFile::remove(filePath)) {
+        safe_sendErrorReply(QDBusError::Failed, "remove file failed.");
+        return;
+    }
+
+    m_mimeManager->updateMimeCache(dir);
+
+    return;
+}
\ No newline at end of file
