@@ -36,9 +36,9 @@
 
 static inline void appendEnvs(const QVariant &var, QStringList &envs)
 {
-    if (var.canConvert(QMetaType::QStringList)) {
+    if (var.canConvert<QStringList>()) {
         envs.append(var.value<QStringList>());
-    } else if (var.canConvert(QMetaType::QString)) {
+    } else if (var.canConvert<QString>()) {
         envs.append(var.value<QString>().split(";", Qt::SkipEmptyParts));
     }
 }
@@ -59,9 +59,10 @@ void ApplicationService::appendExtraEnvironments(QVariantMap &runtimeOptions) co
         appendEnvs(*it, unsetEnvs);
     }
 
-    std::unique_ptr<DConfig> config(DConfig::create(ApplicationServiceID, ApplicationManagerConfig,
-                                                    QString("/%1").arg((id())))); // $appid as subpath
-    if (config->isValid()){
+    std::unique_ptr<DConfig> config(DConfig::create(ApplicationServiceID,
+                                                    ApplicationManagerConfig,
+                                                    QString("/%1").arg((id()))));  // $appid as subpath
+    if (config->isValid()) {
         const QStringList &extraEnvs = config->value(AppExtraEnvironments).toStringList();
         if (!extraEnvs.isEmpty())
             envs.append(extraEnvs);
@@ -78,6 +79,49 @@ void ApplicationService::appendExtraEnvironments(QVariantMap &runtimeOptions) co
     runtimeOptions.insert("unsetEnv", unsetEnvs);
 }
 
+void ApplicationService::processCompatibility(const QString &action, QVariantMap &options, QString &execStr)
+{
+    QString tempExecStr = execStr;
+    auto compatibilityManager = parent()->getCompatibilityManager();
+
+    auto getExec = [action, compatibilityManager](QString desktopID) -> QString {
+        std::optional<QString> execValue;
+        if (!action.isEmpty()) {
+            const auto &actionHeader = QString{"%1%2"}.arg(DesktopFileActionKey, action);
+            execValue = compatibilityManager->getExec(desktopID, actionHeader);
+        } else {
+            execValue = compatibilityManager->getExec(desktopID, DesktopFileEntryKey);
+        }
+
+        if (!execValue.has_value() || execValue->isEmpty()) {
+            return QString();
+        }
+        return execValue.value();
+    };
+
+    auto addEnv = [this, &options, compatibilityManager]() {
+        auto envValue = compatibilityManager->getEnv(m_desktopSource.desktopId(), DesktopFileEntryKey);
+        if (!envValue.isEmpty()) {
+            if (auto it = options.find("env"); it != options.cend()) {
+                auto value = it->toStringList();
+                value.append(envValue);
+                options.insert("env", value);
+            } else {
+                options.insert("env", envValue);
+            }
+        }
+    };
+
+    auto exec = getExec(m_desktopSource.desktopId());
+    if (!exec.isEmpty()) {
+        execStr = exec;
+        addEnv();
+        qInfo() << "get compatibility : " << m_desktopSource.desktopId() << " Exec : " << execStr;
+    }
+
+    return;
+}
+
 ApplicationService::ApplicationService(DesktopFile source,
                                        ApplicationManager1Service *parent,
                                        std::weak_ptr<ApplicationManager1Storage> storage)
@@ -144,6 +188,7 @@ ApplicationService::ApplicationService(DesktopFile source,
 ApplicationService::~ApplicationService()
 {
     detachAllInstance();
+    autoRemoveFromDesktop();
 }
 
 QSharedPointer<ApplicationService> ApplicationService::createApplicationService(
@@ -249,8 +294,8 @@ ApplicationService::Launch(const QString &action, const QStringList &fields, con
         execStr = toString(actionExec.value());
         if (execStr.isEmpty()) {
             qWarning() << "exec value to string failed, try default action.";  // we need this log.
-            break;
         }
+
         break;
     }
 
@@ -278,6 +323,9 @@ ApplicationService::Launch(const QString &action, const QStringList &fields, con
     }
     optionsMap.insert("_builtIn_searchExec", parent()->systemdPathEnv());
 
+    processCompatibility(action, optionsMap, execStr);
+    unescapeEens(optionsMap);
+
     auto cmds = generateCommand(optionsMap);
     auto task = unescapeExec(execStr, fields);
     if (!task) {
@@ -285,8 +333,7 @@ ApplicationService::Launch(const QString &action, const QStringList &fields, con
         return {};
     }
 
-    auto [bin, execCmds, res] = std::move(task);
-    if (bin.isEmpty()) {
+    if (task.LaunchBin.isEmpty()) {
         qCritical() << "error command is detected, abort.";
         safe_sendErrorReply(QDBusError::Failed);
         return {};
@@ -294,55 +341,90 @@ ApplicationService::Launch(const QString &action, const QStringList &fields, con
 
     if (terminal()) {
         // don't change this sequence
-        execCmds.push_front("-C");           // means run a shellscript
-        execCmds.push_front("--keep-open");  // keep terminal open, prevent exit immediately
-        execCmds.push_front("deepin-terminal");
+        cmds.push_back("deepin-terminal");
+        cmds.push_back("--keep-open");  // keep terminal open, prevent exit immediately
+        cmds.push_back("-e");           // run all original execution commands in deepin-terminal
     }
-    cmds.append(std::move(execCmds));
 
     auto &jobManager = parent()->jobManager();
     return jobManager.addJob(
         m_applicationPath.path(),
-        [this, binary = std::move(bin), commands = std::move(cmds)](const QVariant &variantValue) -> QVariant {
-            auto resourceFile = variantValue.toString();
+        [this, task, cmds = std::move(cmds)](const QVariant &value) -> QVariant {  // do not change it to mutable lambda
             auto instanceRandomUUID = QUuid::createUuid().toString(QUuid::Id128);
             auto objectPath = m_applicationPath.path() + "/" + instanceRandomUUID;
-            auto newCommands = commands;
+            auto newCommands = cmds;
 
-            newCommands.push_front(QString{"--SourcePath=%1"}.arg(m_desktopSource.sourcePath()));
-            auto location = newCommands.indexOf(R"(%f)");
-            if (location != -1) {  // due to std::move, there only remove once
-                newCommands.remove(location);
-            }
-
-            if (resourceFile.isEmpty()) {
+            if (value.isNull()) {
+                newCommands.push_front(QString{"--SourcePath=%1"}.arg(m_desktopSource.sourcePath()));
                 newCommands.push_front(QString{R"(--unitName=app-DDE-%1@%2.service)"}.arg(
                     escapeApplicationId(this->id()), instanceRandomUUID));  // launcher should use this instanceId
+                newCommands.append(task.command);
+
                 QProcess process;
-                qDebug() << "run with commands:" << newCommands;
+                qDebug() << "launcher :" << m_launcher << "run with commands:" << newCommands;
                 process.start(m_launcher, newCommands);
                 process.waitForFinished();
                 if (auto code = process.exitCode(); code != 0) {
                     qWarning() << "Launch Application Failed";
                     return QDBusError::Failed;
                 }
+
                 return objectPath;
             }
 
-            auto url = QUrl::fromUserInput(resourceFile);
-            if (!url.isValid()) {  // if url is invalid, passing to launcher directly
-                auto scheme = url.scheme();
-                if (!scheme.isEmpty()) {
-                    // TODO: resourceFile = processRemoteFile(resourceFile);
+            if (task.argNum != -1) {
+                if (task.argNum >= newCommands.size()) {
+                    qCritical() << "task.argNum >= task.command.size()";
+                    return QDBusError::Failed;
                 }
+
+                QStringList rawRes;
+                if (value.canConvert<QStringList>()) {  // from %F, %U
+                    rawRes = value.toStringList();
+                } else if (value.canConvert<QString>()) {  // from %f, %u
+                    rawRes.append(value.toString());
+                } else {
+                    qWarning() << "value type mismatch:" << value;
+                    return QDBusError::Failed;
+                }
+
+                if (task.local) {
+                    std::for_each(rawRes.begin(), rawRes.end(), [](QString &str) {
+                        auto url = QUrl::fromUserInput(str);
+
+                        if (url.isLocalFile()) {
+                            str = url.toLocalFile();
+                            return;
+                        }
+
+                        // TODO: processing remote files
+                        // str = downloadToLocal(url).toLocalFile();
+                    });
+                }
+
+                auto newCmds = task.command;
+                if (task.fieldLocation == -1) {  // single field, e.g. "demo %U"
+                    auto it = newCmds.begin() + task.argNum + 1;
+                    std::for_each(
+                        rawRes.rbegin(), rawRes.rend(), [&newCmds, &it](QString &str) { it = newCmds.insert(it, str); });
+                } else {
+                    auto arg = newCmds.begin() + task.argNum + 1;
+                    arg->insert(task.fieldLocation, rawRes.takeFirst());
+                    ++arg;
+
+                    // expand the rest of res
+                    std::for_each(
+                        rawRes.rbegin(), rawRes.rend(), [&newCmds, &arg](QString &str) { arg = newCmds.insert(arg, str); });
+                }
+
+                newCommands.append(std::move(newCmds));
             }
 
-            // NOTE: resourceFile must be available in the following contexts
-            newCommands.insert(location, resourceFile);
-
+            newCommands.push_front(QString{"--SourcePath=%1"}.arg(m_desktopSource.sourcePath()));
             newCommands.push_front(QString{R"(--unitName=DDE-%1@%2.service)"}.arg(this->id(), instanceRandomUUID));
+
             QProcess process;
-            qDebug() << "run with commands:" << newCommands;
+            qDebug().noquote() << "launcher :" << m_launcher << "run with commands:" << newCommands;
             process.start(getApplicationLauncherBinary(), newCommands);
             process.waitForFinished();
             auto exitCode = process.exitCode();
@@ -350,9 +432,10 @@ ApplicationService::Launch(const QString &action, const QStringList &fields, con
                 qWarning() << "Launch Application Failed";
                 return QDBusError::Failed;
             }
+
             return objectPath;
         },
-        std::move(res));
+        std::move(task.Resources));
 }
 
 bool ApplicationService::SendToDesktop() const noexcept
@@ -549,6 +632,38 @@ QString ApplicationService::X_Deepin_Vendor() const noexcept
     return findEntryValue(DesktopFileEntryKey, "X-Deepin-Vendor", EntryValueType::String).toString();
 }
 
+QString ApplicationService::X_Deepin_CreateBy() const noexcept
+{
+    return findEntryValue(DesktopFileEntryKey, "X-Deepin-CreateBy", EntryValueType::String).toString();
+}
+
+QStringMap ApplicationService::execs() const noexcept
+{
+    QStringMap ret;
+
+    auto mainExec = m_entry->value(DesktopFileEntryKey, "Exec");
+    if (mainExec.has_value()) {
+        ret.insert(DesktopFileEntryKey, mainExec->value<QString>());
+    }
+
+    auto actionList = actions();
+    for (const auto &action : actionList) {
+        auto actionKey = QString{action}.prepend(DesktopFileActionKey);
+        auto value = m_entry->value(actionKey, "Exec");
+        if (!value.has_value()) {
+            continue;
+        }
+        ret.insert(actionKey, value->value<QString>());
+    }
+
+    return ret;
+}
+
+QString ApplicationService::X_CreatedBy() const noexcept
+{
+    return findEntryValue(DesktopFileEntryKey, "X-Created-By", EntryValueType::String).toString();
+}
+
 bool ApplicationService::terminal() const noexcept
 {
     auto val = findEntryValue(DesktopFileEntryKey, "Terminal", EntryValueType::String);
@@ -558,6 +673,12 @@ bool ApplicationService::terminal() const noexcept
     return false;
 }
 
+QString ApplicationService::startupWMClass() const noexcept
+{
+    auto value = findEntryValue(DesktopFileEntryKey, "StartupWMClass", EntryValueType::String);
+    return value.isNull() ? QString{} : value.toString();
+}
+
 qint64 ApplicationService::installedTime() const noexcept
 {
     return m_installedTime;
@@ -630,8 +751,7 @@ bool ApplicationService::autostartCheck(const QString &filePath) const noexcept
 
     QString source = s.value(DesktopFileEntryKey, X_Deepin_GenerateSource).value_or(DesktopEntry::Value{}).toString();
     // file has been removed
-    if (source != m_autostartSource.m_filePath &&
-        filePath != m_autostartSource.m_filePath) {
+    if (source != m_autostartSource.m_filePath && filePath != m_autostartSource.m_filePath) {
         return false;
     }
 
@@ -672,7 +792,6 @@ bool ApplicationService::isAutoStart() const noexcept
         {"*.desktop"},
         QDir::Name | QDir::DirsLast);
 
-
     return autostartCheck(destDesktopFile);
 }
 
@@ -682,7 +801,7 @@ void ApplicationService::setAutoStart(bool autostart) noexcept
         return;
     }
 
-    QDir startDir (getAutoStartDirs().first());
+    QDir startDir(getAutoStartDirs().first());
     if (!startDir.exists() && !startDir.mkpath(startDir.path())) {
         qWarning() << "mkpath " << startDir.path() << "failed";
         safe_sendErrorReply(QDBusError::InternalError);
@@ -895,6 +1014,10 @@ void ApplicationService::resetEntry(DesktopEntry *newEntry) noexcept
     emit terminalChanged();
     emit environChanged();
     emit launchedTimesChanged();
+    emit startupWMClassChanged();
+    emit xDeepinCreatedByChanged();
+    emit execsChanged();
+    emit xCreatedByChanged();
 }
 
 std::optional<QStringList> ApplicationService::unescapeExecArgs(const QString &str) noexcept
@@ -951,162 +1074,221 @@ std::optional<QStringList> ApplicationService::unescapeExecArgs(const QString &s
     return execList;
 }
 
-LaunchTask ApplicationService::unescapeExec(const QString &str, const QStringList &fields) noexcept
+LaunchTask ApplicationService::unescapeExec(const QString &str, QStringList fields) noexcept
 {
     LaunchTask task;
-    auto opt = unescapeExecArgs(str);
+    auto args = unescapeExecArgs(str);
 
-    if (!opt.has_value()) {
+    if (!args) {
         qWarning() << "unescapeExecArgs failed.";
         return {};
     }
 
-    auto execList = std::move(opt).value();
-    if (execList.isEmpty()) {
+    if (args->isEmpty()) {
         qWarning() << "exec format is invalid.";
         return {};
     }
 
-    task.LaunchBin = execList.first();
-    QRegularExpression re{"%[fFuUickdDnNvm]"};
-    auto matcher = re.match(str);
-    if (!matcher.hasMatch()) {
-        task.command.append(std::move(execList));
-        task.Resources.emplace_back(QString{""});  // mapReduce should run once at least
-        return task;
-    }
+    task.LaunchBin = args->first();
+    const QChar percentage{'%'};
+    bool exclusiveField{false};
 
-    auto list = matcher.capturedTexts();
-    if (list.count() != 1) {
-        qWarning() << "invalid exec format, all filed code will be ignored.";
-        for (const auto &code : list) {
-            execList.removeOne(code);
-        }
-        task.command.append(std::move(execList));
-        return task;
-    }
+    for (auto arg = args->begin(); arg != args->end(); ++arg) {
+        QString newArg;
 
-    auto filesCode = list.first().back().toLatin1();
-    auto codeStr = QString(R"(%%1)").arg(filesCode);
-    auto location = execList.indexOf(codeStr);
-    if (location == -1) {
-        qWarning() << "invalid exec format, all filed code will be ignored.";
-        return {};
-    }
-
-    switch (filesCode) {
-    case 'f': {  // Defer to async job
-        task.command.append(std::move(execList));
-        for (const auto &field : fields) {
-            task.Resources.emplace_back(field);
-        }
-    } break;
-    case 'u': {
-        execList.removeAt(location);
-        if (fields.empty()) {
-            task.command.append(execList);
-            break;
-        }
-        if (fields.count() > 1) {
-            qDebug() << R"(fields count is greater than one, %u will only take first element.)";
-        }
-        execList.insert(location, fields.first());
-        task.command.append(execList);
-    } break;
-    case 'F': {
-        execList.remove(location);
-        auto it = execList.begin() + location;
-        for (const auto &field : fields) {
-            auto tmp = QUrl::fromUserInput(field);
-            if (auto scheme = tmp.scheme(); scheme.startsWith("file") or scheme.isEmpty()) {
-                it = execList.insert(it, tmp.toLocalFile());
-            } else {
-                qWarning() << "shouldn't replace %F with an URL:" << field;
-                it = execList.insert(it, field);
+        for (const auto *it = arg->cbegin(); it != arg->cend();) {
+            if (*it != percentage) {
+                newArg.append(*(it++));
+                continue;
             }
-            ++it;
-        }
-        task.command.append(std::move(execList));
-    } break;
-    case 'U': {
-        execList.removeAt(location);
-        auto it = execList.begin() + location;
-        for (const auto &field : fields) {
-            it = execList.insert(it, field);
-            ++it;
-        }
-        task.command.append(std::move(execList));
-    } break;
-    case 'i': {
-        execList.removeAt(location);
-        auto val = m_entry->value(DesktopFileEntryKey, "Icon");
-        if (!val) {
-            qDebug() << R"(Application Icons can't be found. %i will be ignored.)";
-            task.command.append(std::move(execList));
-            return task;
+
+            const auto *code = it + 1;
+            if (code == arg->cend()) {
+                qWarning() << R"(content of exec is invalid, a unterminated % is detected.)";
+                return {};
+            }
+
+            if (*code == percentage) {
+                newArg.append(percentage);
+                it += 2;
+                continue;
+            }
+
+            switch (auto c = code->toLatin1(); c) {
+            case 'f':
+                [[fallthrough]];
+            case 'F': {  // Defer to async job
+                if (exclusiveField) {
+                    qDebug() << QString{"exclusive field is detected again, %%1 will be ignored."}.arg(c);
+                    break;
+                }
+                exclusiveField = true;
+
+                if (fields.empty()) {
+                    qDebug() << QString{"fields is empty, %%1 will be ignored."}.arg(c);
+                    break;
+                }
+
+                if (c == 'F') {
+                    task.Resources.emplace_back(fields);
+                } else {
+                    std::for_each(
+                        fields.begin(), fields.end(), [&task](QString &str) { task.Resources.emplace_back(std::move(str)); });
+                }
+
+                task.argNum = std::distance(args->begin(), arg) - 1;
+                task.fieldLocation = std::distance(arg->cbegin(), it) - 1;
+                task.local = true;
+            } break;
+            case 'u':
+            case 'U': {
+                if (exclusiveField) {
+                    qDebug() << QString{"exclusive field is detected again, %%1 will be ignored."}.arg(c);
+                    break;
+                }
+                exclusiveField = true;
+
+                if (fields.empty()) {
+                    qDebug() << QString{"fields is empty, %%1 will be ignored."}.arg(c);
+                    break;
+                }
+
+                // respect the original url, pass it to exec directly
+                if (c == 'U') {
+                    task.Resources.emplace_back(std::move(fields));
+                } else {
+                    std::for_each(
+                        fields.begin(), fields.end(), [&task](QString &url) { task.Resources.emplace_back(std::move(url)); });
+                }
+
+                task.argNum = std::distance(args->begin(), arg) - 1;
+                task.fieldLocation = std::distance(arg->cbegin(), it) - 1;
+            } break;
+            case 'i': {
+                auto val = m_entry->value(DesktopFileEntryKey, "Icon");
+                if (!val) {
+                    qDebug() << R"(Application Icons can't be found. %i will be ignored.)";
+                    break;
+                }
+
+                auto iconStr = toIconString(val.value());
+                if (iconStr.isEmpty()) {
+                    qDebug() << R"(Icons Convert to string failed. %i will be ignored.)";
+                    break;
+                }
+
+                // split at the end of loop
+                newArg.append(QString{"--icon %1"}.arg(iconStr));
+            } break;
+            case 'c': {
+                auto val = m_entry->value(DesktopFileEntryKey, "Name");
+                if (!val) {
+                    qDebug() << R"(Application Name can't be found. %c will be ignored.)";
+                    break;
+                }
+
+                const auto &rawValue = val.value();
+                if (!rawValue.canConvert<QStringMap>()) {
+                    qDebug() << "Name's underlying type mismatch:" << "QStringMap" << rawValue.metaType().name();
+                    break;
+                }
+
+                auto NameStr = toLocaleString(rawValue.value<QStringMap>(), getUserLocale());
+                if (NameStr.isEmpty()) {
+                    qDebug() << R"(Name Convert to locale string failed. %c will be ignored.)";
+                    break;
+                }
+
+                newArg.append(NameStr);
+            } break;
+            case 'k': {  // ignore all desktop file location for now.
+                newArg.append(m_desktopSource.sourcePath());
+            } break;
+            case 'd':
+            case 'D':
+            case 'n':
+            case 'N':
+            case 'v':
+                [[fallthrough]];  // Deprecated field codes should be removed from the command line and ignored.
+            case 'm': {
+                qDebug() << "field code" << *code << "has been deprecated.";
+            } break;
+            default: {
+                qDebug() << "unknown field code:" << *code << ", ignore it.";
+            }
+            }
+
+            it += 2;  // skip filed code
         }
 
-        auto iconStr = toIconString(val.value());
-        if (iconStr.isEmpty()) {
-            qDebug() << R"(Icons Convert to string failed. %i will be ignored.)";
-            task.command.append(std::move(execList));
-            return task;
-        }
-        auto it = execList.insert(location, iconStr);
-        execList.insert(it, "--icon");
-        task.command.append(std::move(execList));
-    } break;
-    case 'c': {
-        execList.removeAt(location);
-        auto val = m_entry->value(DesktopFileEntryKey, "Name");
-        if (!val) {
-            qDebug() << R"(Application Name can't be found. %c will be ignored.)";
-            task.command.append(std::move(execList));
-            return task;
+        // unescapeExecArgs()函数中使用了遵循POSIX标准的wordexp，可以正确解析被引号包裹的整体，解析成参数列表，
+        // 被分割的都是一个个整体，若分割后的参数在这里还能再按空格分割，
+        // 则说明这个参数被包裹在一个引号中作为了一个整体，此时我们不能再分割这个参数
+        const bool noSplit = (*arg).split(' ').size() > 1;
+        QStringList newArgList;
+        if (noSplit) {
+            newArgList = {newArg};
+        } else {
+            newArgList = newArg.split(' ', Qt::SkipEmptyParts);
         }
 
-        const auto &rawValue = val.value();
-        if (!rawValue.canConvert<QStringMap>()) {
-            qDebug() << "Name's underlying type mismatch:" << "QStringMap" << rawValue.metaType().name();
-            task.command.append(std::move(execList));
-            return task;
+        if (!newArgList.isEmpty()) {
+            task.command.append(std::move(newArgList));
         }
-
-        auto NameStr = toLocaleString(rawValue.value<QStringMap>(), getUserLocale());
-        if (NameStr.isEmpty()) {
-            qDebug() << R"(Name Convert to locale string failed. %c will be ignored.)";
-            task.command.append(std::move(execList));
-            return task;
-        }
-        execList.insert(location, NameStr);
-        task.command.append(std::move(execList));
-    } break;
-    case 'k': {  // ignore all desktop file location for now.
-        execList.removeAt(location);
-        task.command.append(std::move(execList));
-    } break;
-    case 'd':
-    case 'D':
-    case 'n':
-    case 'N':
-    case 'v':
-        [[fallthrough]];  // Deprecated field codes should be removed from the command line and ignored.
-    case 'm': {
-        execList.removeAt(location);
-        task.command.append(std::move(execList));
-    } break;
-    default: {
-        qDebug() << "unrecognized file code.";
-    }
     }
 
     if (task.Resources.isEmpty()) {
-        task.Resources.emplace_back(QString{""});  // mapReduce should run once at least
+        task.Resources.emplace_back(QVariant{});  // mapReduce should run once at least
     }
 
+    qInfo() << "after unescape exec:" << task.LaunchBin << task.command << task.Resources;
     return task;
 }
 
+void ApplicationService::unescapeEens(QVariantMap &options) noexcept
+{
+    if (options.find("env") == options.end()) {
+        return;
+    }
+    QStringList result;
+    auto envs = options["env"];
+    for (const QString &var : envs.toStringList()) {
+        wordexp_t p;
+        if (wordexp(var.toStdString().c_str(), &p, 0) == 0) {
+            for (size_t i = 0; i < p.we_wordc; i++) {
+                result << QString::fromLocal8Bit(p.we_wordv[i]);  // 将结果转换为QString
+            }
+            wordfree(&p);
+        } else {
+            return;
+        }
+    }
+
+    options.insert("env", result);
+}
+
+void ApplicationService::autoRemoveFromDesktop() const noexcept
+{
+    auto dir = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+    if (dir.isEmpty()) {
+        return;
+    }
+
+    QFileInfo desktopFile{QDir{dir}.filePath(m_desktopSource.desktopId() + ".desktop")};
+
+    if (!desktopFile.isSymbolicLink()) {
+        qDebug() << desktopFile.filePath() << " is not symbolicLink";
+        return;
+    }
+
+    QFile file{desktopFile.filePath()};
+    auto success = file.remove();
+    if (!success) {
+        qWarning() << "remove desktop file failed:" << file.errorString();
+        return;
+    }
+}
+
 QVariant ApplicationService::findEntryValue(const QString &group,
                                             const QString &valueKey,
                                             EntryValueType type,
